@@ -16,6 +16,20 @@ class AgriculturalProduction(BaseModel):
     variableCosts: float
     landValue: float
     
+class AgriculturalProductionDTO(BaseModel):
+    id: Optional[int] = None
+    farmId: int
+    yearId: int
+    productGroupId: Optional[int] = None
+    valueSales: float
+    quantitySold: float
+    cropProduction: float
+    irrigatedArea: float
+    cultivatedArea: float
+    organicProductionType: str
+    variableCosts: float
+    landValue: float
+    
 class LivestockProduction(BaseModel):
     id: Optional[int] = None
     farmId: int
@@ -127,6 +141,13 @@ class HolderFarmYearData(BaseModel):
     holderSuccessors: int
     holderSuccessorsAge: int
     holderFamilyMembers: int
+    
+class FarmYearSubsidy(BaseModel):
+    id: Optional[int] = None
+    farmId: int
+    yearId: int
+    policyId: int
+    value: float
 
 class ValueToLPDTO(BaseModel):
     farmId: int
@@ -227,5 +248,5 @@ class AgroManagementDecisionFromLP(BaseModel):
 
 class DataToLPDTO(BaseModel):
     values: List[ValueToLPDTO]
-    agriculturalProductions: List[AgriculturalProduction]
+    agriculturalProductions: List[AgriculturalProductionDTO]
 
